
/*
 * Copyright (C) JOSH Development Team
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Please visit www.joshvm.org if you need additional information or
 * have any questions.
 */
import java.io.IOException;

import org.joshvm.ui.Color;
import org.joshvm.ui.Container;
import org.joshvm.ui.Display;
import org.joshvm.ui.PointGroup;
import org.joshvm.ui.Screen;
import org.joshvm.ui.widget.Canvas;
import org.joshvm.ui.widget.Image;

public class CanvasTest implements UITest {
    private Display display = Display.getDisplay();

    private void Canvas_1(Container container) {
        Canvas canvas = new Canvas(50, 50);
        canvas.setPos(300, 200);
        canvas.setSize(150, 100);
        canvas.setBackgroundColor(new Color(0xFF00FF00));
        canvas.fill(new Color(0xFF0000FF));
        container.addWidget(canvas);
    }

    private void Canvas_2(Container container) {
        Canvas canvas = new Canvas(50, 50);
        canvas.setPos(300, 200);
        canvas.setSize(100, 100);
        canvas.fill(new Color(0x7F007F00));
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        for (short i = 0; i < 25; i++) {
            for (short j = 0; j < 40; j++) {
                canvas.setPixel(i, j, new Color(0xFFFFFFFF));
            }
        }
        container.addWidget(canvas);
    }

    private void Canvas_3(Container container) {
        Canvas canvas = new Canvas(150, 150);
        canvas.setPos(300, 200);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        container.addWidget(canvas);
        PointGroup pg = new PointGroup();
        pg.addPoint(10, 20);
        pg.addPoint(10, 120);
        pg.addPoint(140, 120);
        canvas.setLineColorOfDraw(Color.GREEN);
        canvas.setLineWidthOfDraw(2);
        canvas.setLineDashWidthOfDraw(10);
        canvas.setLineDashGapOfDraw(10);
        canvas.drawLine(pg);
    }

    private void Canvas_4(Container container) {
        Canvas canvas = new Canvas(50, 50);
        canvas.setPos(300, 200);
        canvas.setSize(75, 75);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        container.addWidget(canvas);
        PointGroup pg = new PointGroup();
        pg.addPoint(10, -10);
        pg.addPoint(10, 10);
        pg.addPoint(40, 0);
        pg.addPoint(30, 30);
        pg.addPoint(10, 20);
        pg.addPoint(100, 100);
        pg.addPoint(10, 10);
        canvas.setLineColorOfDraw(Color.PURPLE);
        canvas.drawLine(pg);
    }

    private void Canvas_5(Container container) {
        Canvas canvas = new Canvas(100, 100);
        canvas.setPos(300, 200);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        container.addWidget(canvas);
        PointGroup pg = new PointGroup();
        pg.addPoint(20, 20);
        pg.addPoint(50, 20);
        pg.addPoint(50, 50);
        pg.addPoint(20, 50);
        pg.addPoint(-10, 35);
        canvas.setBackgroundColorOfDraw(Color.BLUE);
        canvas.drawPolygon(pg);
    }

    private void Canvas_6(Container container) {
        Canvas canvas = new Canvas(100, 100);
        canvas.setPos(300, 200);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        container.addWidget(canvas);
        canvas.setBackgroundColorOfDraw(Color.WHITE);
        canvas.setLineColorOfDraw(Color.GREEN);
        canvas.setLineWidthOfDraw(3);
        canvas.setRectRadiusOfDraw(5);
        canvas.setShadowColorOfDraw(Color.GRAY);
        canvas.setShawdowWidthOfDraw(3);
        canvas.setShadowOffsetXOfDraw(-5);
        canvas.setShadowOffsetYOfDraw(-5);
        canvas.drawRect(20, 20, 70, 30);
    }

    private void Canvas_7(Container container) {
        Canvas canvas = new Canvas(100, 100);
        canvas.setPos(300, 200);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        container.addWidget(canvas);
        // canvas.drawArc(49, 49, 50, -180, -90);
        canvas.setLineColorOfDraw(Color.BLUE);
        canvas.setLineWidthOfDraw(3);
        canvas.drawArc(50, 50, 40, 0, 270);
    }

    private void Canvas_8(Container container) {
        Canvas canvas = new Canvas(100, 100);
        canvas.setPos(300, 200);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        container.addWidget(canvas);
        canvas.setTextColorOfDraw(Color.GREEN);
        canvas.setTextLetterSpaceOfDraw(20);
        canvas.setTextLineSpaceOfDraw(20);
        canvas.drawText("你好\nWorld", 10, 10);
    }

    private void Canvas_9(Container container) {
        Canvas canvas = new Canvas(200, 200);
        canvas.setPos(300, 100);
        canvas.setBackgroundColor(new Color(0xFF0000FF));
        container.addWidget(canvas);
        try {
            canvas.drawImage("/package.png", 50, 20);
        } catch (IOException e) {
            e.printStackTrace();
        }

        canvas.setImageAngleOfDraw(1800);
        canvas.setImagePivotOfDraw(25, 25);
        try {
            canvas.drawImage("/package.png", 120, 20);
        } catch (IOException e) {
            e.printStackTrace();
        }

        canvas.resetPropertyValuesOfDraw();
        canvas.setImageRecolorOfDraw(Color.GREEN);
        canvas.setImageZoomOfDraw(1.5);
        try {
            canvas.drawImage("/package.png", 100, 100);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private void Canvas_10(Container container) {
        Canvas canvas = new Canvas(200, 200);
        canvas.setPos(100, 100);
        canvas.fill(new Color(0xFF0000FF));
        container.addWidget(canvas);
        try {
            canvas.drawImage("/package.png", 50, 20);
        } catch (IOException e) {
            e.printStackTrace();
        }

        canvas.setImageAngleOfDraw(1800);
        canvas.setImagePivotOfDraw(25, 25);
        try {
            canvas.drawImage("/package.png", 120, 20);
        } catch (IOException e) {
            e.printStackTrace();
        }

        Image image = canvas.getImage();
        image.setPos(400, 100);
        container.addWidget(image);

        canvas.resetPropertyValuesOfDraw();
        canvas.setImageRecolorOfDraw(Color.GREEN);
        canvas.setImageZoomOfDraw(1.5);
        try {
            canvas.drawImage("/package.png", 100, 100);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void start() {
        Screen screen = new Screen();
        screen.setBackgroundColor(new Color(0xFFFFFF00));
        display.setScreen(screen);

        Canvas_10(screen);
    }

    public void stop() {
        display.stop();
    }
}
