
/*
 * Copyright (C) JOSH Development Team
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Please visit www.joshvm.org if you need additional information or
 * have any questions.
 */
import java.io.IOException;

import org.joshvm.ui.Area;
import org.joshvm.ui.Color;
import org.joshvm.ui.Container;
import org.joshvm.ui.Display;
import org.joshvm.ui.Font;
import org.joshvm.ui.Screen;
import org.joshvm.ui.widget.Canvas;
import org.joshvm.ui.widget.Label;

public class FontTest implements UITest {
    private Display display = Display.getDisplay();

    private void Font_1(Container container) {
        Label l = new Label();
        l.setPos(100, 100);
        l.setPadding(10);
        l.setText("Hello World!\n" + "树 木");
        l.setBackgroundColor(Color.GREEN);
        Font font = Font.getFont(16);
        l.setTextFont(font);
        container.addWidget(l);
    }

    private void Font_2(Container container) {
        Font font = Font.getDefaultFont();
        System.out.println("default font: " + font.getName() + ","
                + font.getSize() + "," + font.getStyle());

        Label l = new Label();
        l.setPos(100, 100);
        l.setPadding(10);
        l.setText("Hello World!\n" + "树 木");
        container.addWidget(l);

        l = new Label();
        l.setPos(200, 200);
        l.setPadding(10);
        l.setText("你好");
        font = Font.getFont(24);
        l.setTextFont(font);
        font = Font.getFont(24, Font.STYLE_ITALIC);
        l.setTextFont(font);
        System.gc();
        container.addWidget(l);

        l = new Label();
        l.setPos(300, 300);
        l.setPadding(10);
        l.setText("世界");
        font = Font.getFont(32, Font.STYLE_BOLD | Font.STYLE_ITALIC);
        System.out.println("font: " + font.getName() + "," + font.getSize()
                + "," + font.getStyle());
        l.setTextFont(font);
        container.addWidget(l);
    }

    private void Font_3(Container container) {
        String str = "Hello";
        Font font = Font.getFont(16);
        Area area = font.StringArea(str);
        System.out.println(area);

        font = Font.getFont(24);
        area = font.StringArea(str);
        System.out.println(area);

        area = font.StringArea(str + "\n" + str);
        System.out.println(area);

        Canvas canvas = new Canvas(200, 100);
        canvas.setPos(300, 200);
        canvas.setBackgroundColor(new Color(0xFFFF0000));
        font = Font.getFont(16);
        area = font.StringArea(str, 2, 0);
        System.out.println(area);
        canvas.setTextFontOfDraw(font);
        canvas.setTextLetterSpaceOfDraw(2);
        canvas.setTextDecorOfDraw(Canvas.TEXT_DECOR_UNDERLINE);
        canvas.drawText(str, 10, 10);
        canvas.drawText("world", 10 + 2 + area.getWidth(), 10);
        container.addWidget(canvas);
    }

    private void Font_4(Container container) {
        Label l = new Label();
        l.setPos(100, 100);
        l.setPadding(10);
        l.setText("你好早上好bcdM");
        l.setBackgroundColor(Color.GREEN);
        Font font;
        try {
            font = Font.createFont("/test.ttf", 24);
            System.out.println("font: " + font.getName() + "," + font.getSize()
            + "," + font.getStyle());
            l.setTextFont(font);
            l.setTextDecor(Label.TEXT_DECOR_UNDERLINE | Label.TEXT_DECOR_STRIKETHROUGH);
        } catch (IOException e) {
            e.printStackTrace();
        }
        container.addWidget(l);

        l = new Label();
        l.setPos(100, 200);
        l.setPadding(10);
        l.setText("你好早上好bcdM");
        l.setBackgroundColor(Color.GREEN);
        font = Font.getFont(24);
        System.out.println("font: " + font.getName() + "," + font.getSize()
        + "," + font.getStyle());
        l.setTextFont(font);
        l.setTextDecor(Label.TEXT_DECOR_UNDERLINE);
        container.addWidget(l);
    }

    public void start() {
        Screen screen = new Screen();
        screen.setBackgroundColor(new Color(0xFFFFFF00));
        display.setScreen(screen);

        Font_4(screen);
    }

    public void stop() {
        display.stop();
    }
}
