
/*
 * Copyright (C) JOSH Development Team
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Please visit www.joshvm.org if you need additional information or
 * have any questions.
 */
import org.joshvm.ui.Color;
import org.joshvm.ui.Container;
import org.joshvm.ui.Display;
import org.joshvm.ui.Screen;
import org.joshvm.ui.UIObject;
import org.joshvm.ui.layout.Flex;
import org.joshvm.ui.widget.Button;
import org.joshvm.ui.widget.Label;

public class LayoutTest implements UITest {
    private Display display = Display.getDisplay();

    private void Align_1(Container container) {
        Container c1 = new Container();
        c1.setSize(400, 200);
        c1.setPos(200, 200);
        container.addContainer(c1);

        Label l = new Label();
        l.setText("Center");
        l.setAlign(Label.ALIGN_CENTER, Label.ALIGN_CENTER);

        Label l2 = new Label();
        l2.setText("Left Bottom");
        l2.setAlign(Label.ALIGN_LEFT, Label.ALIGN_BOTTOM);

        Label l3 = new Label();
        l3.setText("Right Top");
        l3.setAlign(Label.ALIGN_RIGHT, Label.ALIGN_TOP);

        c1.addWidget(l);
        c1.addWidget(l2);
        c1.addWidget(l3);
    }

    private void Flex_1(Container container) {
        Container c1 = new Container();
        c1.setPadding(5);
        c1.setSize(400, 200);
        c1.setPos(200, 200);
        for (int i = 0; i < 5; i++) {
            Button btn = new Button("Button" + i);
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW_WRAP);
        layout.setMainAlign(Flex.FLEX_ALIGN_SPACE_EVENLY);
        c1.updateLayout(layout);
        container.addContainer(c1);
    }

    private void Flex_2(Container container) {
        Container c1 = new Container();
        c1.setPadding(5);
        c1.setSize(400, 200);
        c1.setPos(200, 200);
        for (int i = 0; i < 14; i++) {
            Button btn = new Button("Button" + i);
            btn.setSize(80, 40);
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_COLUMN_WRAP);
        layout.setMainAlign(Flex.FLEX_ALIGN_SPACE_BETWEEN);
        c1.updateLayout(layout);
        container.addContainer(c1);
    }

    private void Flex_3(Container container) {
        Container c1 = new Container();
        c1.setPadding(5);
        c1.setSize(UIObject.SIZE_CONTENT, 200);
        c1.setPos(100, 100);
        c1.setColumnPadding(0);
        for (int i = 0; i < 14; i++) {
            Button btn = new Button("Button" + i);
            if (i == 6 || i == 7 || i == 8) {
                btn.forceNewTrack(true);
            }
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_COLUMN_WRAP);
        layout.setMainAlign(Flex.FLEX_ALIGN_SPACE_AROUND);
        c1.updateLayout(layout);
        container.addContainer(c1);
    }

    private void Flex_4(Container container) {
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW_WRAP);
        layout.setMainAlign(Flex.FLEX_ALIGN_SPACE_AROUND);

        Container c1 = new Container();
        c1.setPadding(5);
        c1.setSize(300, UIObject.SIZE_CONTENT);
        c1.setPos(100, 100);
        for (int i = 0; i < 3; i++) {
            Button btn = new Button("Button" + i);
            btn.setFlexGrow(i);
            c1.addWidget(btn);
        }
        c1.updateLayout(layout);
        container.addContainer(c1);

        Container c2 = new Container();
        c2.setPadding(5);
        c2.setSize(500, UIObject.SIZE_CONTENT);
        c2.setPos(100, 200);
        for (int i = 0; i < 3; i++) {
            Button btn = new Button("Button" + (i + 3));
            btn.setSize(80, UIObject.SIZE_CONTENT);
            btn.setFlexGrow(i);
            btn.setTextColor(Color.CYAN);
            btn.setTextAlign(UIObject.ALIGN_CENTER);
            c2.addWidget(btn);
        }
        c2.updateLayout(layout);
        container.addContainer(c2);
    }

    private void IgnoreLayout_1(Container container) {
        Container c1 = new Container();
        c1.setPadding(5);
        c1.setSize(300, 150);
        c1.setPos(200, 200);
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            if (i == 5) {
                btn.setPos(50, 50);
                btn.setBackgroundColor(Color.GREEN);
                btn.setIgnoreLayout(true);
            }
            if (i == 6) {
                btn.setBackgroundColor(Color.MAGENTA);
                btn.setPos(50, 100);
            }
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW_WRAP);
        c1.updateLayout(layout);
        container.addContainer(c1);
    }

    private void Floating_1(Container container) {
        Container c1 = new Container();
        c1.setPadding(5);
        c1.setSize(300, 150);
        c1.setPos(200, 200);
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            if (i == 5) {
                btn.setPos(50, 50);
                btn.setBackgroundColor(Color.GREEN);
                btn.setFloating(true);
            }
            if (i == 6) {
                btn.setBackgroundColor(Color.MAGENTA);
                btn.setPos(50, 100);
            }
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW_WRAP);
        c1.updateLayout(layout);
        container.addContainer(c1);
    }

    public void start() {
        Screen screen = new Screen();
        screen.setBackgroundColor(new Color(0xFFFFFF00));
        display.setScreen(screen);

        IgnoreLayout_1(screen);
    }

    public void stop() {
        display.stop();
    }
}
