
/*
 * Copyright (C) JOSH Development Team
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Please visit www.joshvm.org if you need additional information or
 * have any questions.
 */
import org.joshvm.ui.AbstractUIObject;
import org.joshvm.ui.Color;
import org.joshvm.ui.Container;
import org.joshvm.ui.Display;
import org.joshvm.ui.Screen;
import org.joshvm.ui.UIObject;
import org.joshvm.ui.layout.Flex;
import org.joshvm.ui.listener.ScrollListener;
import org.joshvm.ui.widget.Button;

public class ScrollTest implements UITest {
    private Display display = Display.getDisplay();

    private void Scroll_1(Container container) {
        Container c1 = new Container();
        c1.setSize(400, 200);
        c1.setAlign(UIObject.ALIGN_CENTER, UIObject.ALIGN_CENTER);
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW);
        c1.updateLayout(layout);
        c1.setScrollbarMode(AbstractUIObject.SCROLLBAR_MODE_OFF);
        container.addContainer(c1);
    }

    private void Scroll_2(Container container) {
        Container c1 = new Container();
        c1.setSize(400, 200);
        c1.setAlign(UIObject.ALIGN_CENTER, UIObject.ALIGN_CENTER);
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            Color color = btn.getBackgroundColor();
            color.setAlphaPercent((i + 1) * 10);
            btn.setBackgroundColor(color);
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW);
        c1.updateLayout(layout);
        c1.setScrollbarMode(AbstractUIObject.SCROLLBAR_MODE_ACTIVE);
        c1.getScrollbar().setBackgroundColor(Color.RED);
        c1.getScrollbar().setWidth(10);
        container.addContainer(c1);
    }

    private void Scroll_3(Container container) {
        Container c1 = new Container();
        c1.setSize(400, 200);
        c1.setAlign(UIObject.ALIGN_CENTER, UIObject.ALIGN_CENTER);
        Button btn7 = null;
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            c1.addWidget(btn);
            if (i == 7) {
                btn7 = btn;
            }
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW);
        c1.updateLayout(layout);
        container.addContainer(c1);
        System.out.println("area of container is " + c1.getCoordinates());
        System.out.println("area1 of btn is " + btn7.getCoordinates());
        System.out.println("scroll1 of container is " + c1.getScrollX() + ","
                + c1.getScrollY() + " " + c1.getScrollLeft() + ","
                + c1.getScrollRight() + "," + c1.getScrollTop() + ","
                + c1.getScrollBottom());
        btn7.scrollToView(true);
        System.out.println("area2 of btn is " + btn7.getCoordinates());
        System.out.println("scroll2 of container is " + c1.getScrollX() + ","
                + c1.getScrollY() + " " + c1.getScrollLeft() + ","
                + c1.getScrollRight() + "," + c1.getScrollTop() + ","
                + c1.getScrollBottom());
        try {
            Thread.sleep(3000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        c1.scrollToX(c1.getScrollX() + c1.getScrollRight(), true);
        System.out.println("area3 of btn is " + btn7.getCoordinates());
        System.out.println("scroll3 of container is " + c1.getScrollX() + ","
                + c1.getScrollY() + " " + c1.getScrollLeft() + ","
                + c1.getScrollRight() + "," + c1.getScrollTop() + ","
                + c1.getScrollBottom());
    }

    private void Scroll_4(Container container) {
        Container c1 = new Container();
        c1.setSize(400, 200);
        c1.setAlign(UIObject.ALIGN_CENTER, UIObject.ALIGN_CENTER);
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_COLUMN);
        c1.updateLayout(layout);
        c1.setScrollDirection(AbstractUIObject.SCROLL_DIR_BOTTOM);
        container.addContainer(c1);
    }

    private void Scroll_5(Container container) {
        Container c1 = new Container();
        c1.setSize(400, 200);
        c1.setAlign(UIObject.ALIGN_CENTER, UIObject.ALIGN_CENTER);
        for (int i = 0; i < 10; i++) {
            Button btn = new Button("Button" + i);
            c1.addWidget(btn);
        }
        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW);
        c1.updateLayout(layout);
        c1.setScrollbarMode(AbstractUIObject.SCROLLBAR_MODE_ACTIVE);
        c1.getObjectOfState(AbstractUIObject.STATE_SCROLLED)
                .setBackgroundColor(Color.MAGENTA);
        c1.setScrollListener(new ScrollListener() {

            public void onScrollBegin(UIObject target) {
                System.out.println(
                        "begin scroll at " + System.currentTimeMillis());
                System.out.println("isScrolled:"
                        + ((Container) target).isScrolled() + " scroll x:"
                        + ((Container) target).getScrollX());
            }

            public void onScrolling(UIObject target) {
                System.out
                        .println("scrolling at " + System.currentTimeMillis());
                System.out.println("isScrolled:"
                        + ((Container) target).isScrolled() + " scroll x:"
                        + ((Container) target).getScrollX());
            }

            public void onScrollEnd(UIObject target) {
                System.out
                        .println("end scroll at " + System.currentTimeMillis());
                System.out.println("isScrolled:"
                        + ((Container) target).isScrolled() + " scroll x:"
                        + ((Container) target).getScrollX());
            }
        });
        container.addContainer(c1);
        try {
            Thread.sleep(5000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        c1.scrollToX(c1.getScrollRight());
    }

    public void start() {
        Screen screen = new Screen();
        screen.setBackgroundColor(new Color(0xFFFFFF00));
        display.setScreen(screen);

        Scroll_5(screen);
    }

    public void stop() {
        display.stop();
    }
}
